BalderHub Auth
==============


.. note::
    Please note, this package is still under development. If you would like to contribute, take a look into the
    `project <https://github.com/balder-dev/balderhub-auth/>`_.

    More scenarios and features will be released soon, specially for permission handling.

This is a BalderHub package for the `Balder <https://docs.balder.dev/>`_ test framework. If you are new to Balder check
out the `official documentation <https://docs.balder.dev>`_ first.

What can you do with this project?
----------------------------------

This is a BalderHub project that provides different features and scenarios for testing authentification and authorization (permissions, login, ...).


.. toctree::
    :maxdepth: 2

    installation.rst
    topic_intro.rst
    scenarios.rst
    features.rst
    examples.rst
    utilities.rst
    contrib.rst
